@@ -2,7 +2,7 @@
 from sqlalchemy import create_engine
 import pandas as pd
 import os
-import csv
+import time
 
 
 def stackTodb(dataFrame, dbTableName):
@@ -45,17 +45,7 @@ def csvEncoder(csv_folder, csv_folder_encoding):
         csv_encoding(csv_folder + "\\" + fileList[i], csv_folder_encoding)
         print(fileList[i] + " is encoded")
 
-
 def commonPreprocess(dataframe):
-    # brand명 기준으로 이후 6글자 추출
-    dataframe['brand'] = dataframe['brand'].str.lower()
-    dataframe['title'] = dataframe['title'].str.lower()
-    dataframe['product_name_1'] = dataframe.apply(lambda x: x['brand'] + ' ' + ' '.join(x['title'].split(x['brand'])[1].split()[:5]) if x['brand'] in x['title'] else '', axis=1)
-
-    return dataframe
-
-def commonPreprocess(dataframe):
-    # brand명 기준으로 이후 6글자 추출
     dataframe['brand'] = dataframe['brand'].str.lower()
     dataframe['title'] = dataframe['title'].str.lower()
     try:
@@ -71,11 +61,9 @@ def keywordPool(csv):
     pool.columns = column
 
     poolList = {}
-    #중복 제거한 브랜드 리스트
     brandList = pool.drop_duplicates(['brand'])['brand'].to_list()
     for i in range(len(brandList)):
         string = pool.loc[pool['brand'] == brandList[i]]
-        # 브랜드 네임 : 키워드 풀
         poolList[brandList[i]] = string['string'].to_list()
 
     return poolList
@@ -107,72 +95,69 @@ def addPoolColumn(dataframe, keyword_pool):
     pool = keywordPool(keyword_pool)
     title_mapping = titleSummaryMaker(keyword_pool)
 
-    #키워드 풀에서 검색 후 포함되는 문자열은 리스트로 반환
     dataframe['title_summary_temp'] = dataframe.apply(lambda x: [i for i in pool.get(x['brand'], []) if i in x['title']], axis=1)
     dataframe['title_summary_temp'] = dataframe['title_summary_temp'].apply(lambda x: x if len(x) > 0 else '')
 
-    #리스트 안에서 문자열이 가장 긴 값 리턴
     dataframe['title_summary_temp'] = dataframe['title_summary_temp'].apply(lambda x: max(x, key=lambda y: len(y)) if x else '')
 
-    #키워드 분류로 한번 더 매핑
     final_df = pd.merge(dataframe, title_mapping, how='left', on='title_summary_temp')
 
     return final_df
 
 def csvPreprocess(csv_folder, csv_folder_cleaned, csv_folder_encoding):
-    # csv 줄밀림 정제
+
     csvEncoder(csv_folder, csv_folder_encoding)
     csvCleaner(csv_folder_encoding, csv_folder_cleaned)
     
 
-def csvImporter_NEW(csv_folder, csv_folder_cleaned, csv_folder_encoding, keyword_pool):
+def csvImporter_NEW(csv_folder_cleaned, keyword_pool):
     column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
-    
-    # 키워드 풀 가져오기
-    pool = keywordPool(keyword_pool)
-    title_mapping = titleSummaryMaker(keyword_pool)
 
     fileList = os.listdir(csv_folder_cleaned)
     for i in range(len(fileList)):
         dataframe = pd.read_csv(csv_folder_cleaned + "\\" + fileList[i], sep=',', engine='python', encoding='latin-1')
         dataframe.columns = column_name
         
-        #파일명 제일 앞단에 삽입
         dataframe.insert(0, "file_name", fileList[i][:-4], True)
         
-        # csv 파일 내 브랜드, 타이틀명 소문자 변경
         dataframe['brand'] = dataframe['brand'].str.lower()
         dataframe['title'] = dataframe['title'].str.lower()
+        dataframe['title'] = dataframe['title'].str.replace('â', '')
+        dataframe['title'] = dataframe['title'].str.replace('Â', '')
 
         ##### no pool
         if "Laptops" in fileList[i]:
             db_table_name = 'tb_stackline_laptops'
             # commonPreprocess(dataframe)
+            print("-----No Pool Check-----")
             stackTodb(dataframe, db_table_name)
 
         if "Earbud" in fileList[i]:
             db_table_name = 'tb_stackline_earbuds'
             # commonPreprocess(dataframe)
+            print("-----No Pool Check-----")
             stackTodb(dataframe, db_table_name)
 
         ##### pool
         if "Watches" in fileList[i]:
             db_table_name = 'tb_stackline_watches'
-            stackTodb(addPoolColumn(db_table_name), db_table_name)
+            print("-----Pool Check-----")
+            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name)
 
         if "Tablets" in fileList[i]:
             db_table_name = 'tb_stackline_tablets'
-            stackTodb(addPoolColumn(db_table_name), db_table_name)
+            print("-----Pool Check-----")
+            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name)
 
         if "Phones" in fileList[i]:
             db_table_name = 'tb_stackline_smartphones'
-            stackTodb(addPoolColumn(db_table_name), db_table_name)
+            print("-----Pool Check-----")
+            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name)
 
 
-def keywordCheck(csv_folder, csv_folder_cleaned, csv_folder_encoding, pool_check_folder, keyword_pool):
+def keywordCheck(csv_folder_cleaned, pool_check_folder, keyword_pool):
     column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
 
-    # 키워드 풀 가져오기
     pool = keywordPool(keyword_pool)
     title_mapping = titleSummaryMaker(keyword_pool)
 
@@ -181,37 +166,36 @@ def keywordCheck(csv_folder, csv_folder_cleaned, csv_folder_encoding, pool_check
         dataframe = pd.read_csv(csv_folder_cleaned + "\\" + fileList[i], sep=',', engine='c', encoding='latin-1')
         dataframe.columns = column_name
         
-        #파일명 제일 앞단에 삽입
         dataframe.insert(0, "file_name", fileList[i][:-4], True)
 
-        # csv 파일 내 브랜드, 타이틀명 소문자 변경
         dataframe['brand'] = dataframe['brand'].str.lower()
         dataframe['title'] = dataframe['title'].str.lower()
+        dataframe['title'] = dataframe['title'].str.replace('â', '')
+        dataframe['title'] = dataframe['title'].str.replace('Â', '')
+        dataframe['title'] = dataframe['title'].str.replace('fã¼r', 'for')
+        dataframe['title'] = dataframe['title'].str.replace('ã', '')
 
-        # sales unit / retail sales 컬럼 추가
         check_frame = dataframe[['brand', 'title', 'units_sold', 'retail_sales']].groupby(by=['brand', 'title'], as_index=False).sum()
 
-        # 키워드 풀과 겹치는 스트링 반환 
         check_frame['title_summary_list'] = check_frame.apply(lambda x: [i for i in pool.get(x['brand'], []) if i in x['title']], axis=1)
         check_frame['title_summary_list'] = check_frame['title_summary_list'].apply(lambda x: x if len(x) > 0 else '')
              
-        # 리스트 중 가장 문자열이 긴 값 리턴
         check_frame['title_summary_temp'] = check_frame['title_summary_list'].apply(lambda x: max(x, key=lambda y: len(y)) if x else '')
         
-        #키워드 분류로 한번 더 매핑
         final_df = pd.merge(check_frame, title_mapping, how='left', on='title_summary_temp')
 
-        #pool 폴더로 검수용 파일 반환
-        final_df.to_csv(pool_check_folder + "\\Keyword_Check_" + fileList[i], sep=',', na_rep='', encoding='utf-8-sig', index = False)
-        print("Keyword_Check_" + fileList[i] + "is created")
+        final_df.to_csv(pool_check_folder + "\\Keyword_Check_" + str(time.strftime('%Y%m%d-%H%M%S', time.localtime())) + "_" + fileList[i], sep=',', na_rep='', encoding='utf-8-sig', index = False)
+        print("Keyword_Check_" + fileList[i] + " is created")
 
 
 # if __name__ == "__main__":
-# #     db_table_name = 'tb_stackline_dataset'
-#     csv_folder = "csvFolder"
-#     csv_folder_cleaned = "csvFolder_cleaned"
-#     keyword_pool = "csvimporteract\\tablet_phone_pool.csv"
-     
-# #     csvImporter(csv_folder, csv_folder_cleaned, db_table_name)
-
-#     csvImporter_NEW(csv_folder, csv_folder_cleaned, keyword_pool)
\ No newline at end of file
+#     # keywordCheck
+#     csv_folder = ""
+#     csv_folder_cleaned = ""
+#     csv_folder_encoding = ""
+#     keyword_pool = ""
+#     pool_check_folder = ""
+    
+#     csvPreprocess(csv_folder, csv_folder_cleaned, csv_folder_encoding)
+#     keywordCheck(csv_folder_cleaned, pool_check_folder, keyword_pool)
+#     csvImporter_NEW(csv_folder_cleaned, keyword_pool)
\ No newline at end of file
